package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.BusinessArticle;
import com.ruoyi.mall.domain.Vo.BusinessArticleVo;

/**
 * 帖子管理Service接口
 * 
 * @author ruoyi
 * @date 2023-10-17
 */
public interface IBusinessArticleService 
{
    /**
     * 查询帖子管理(后台）
     * 
     * @param articleId 帖子管理主键
     * @return 帖子管理
     */
    public BusinessArticleVo selectBusinessArticleByArticleId(Long articleId);

    /**
     * 查询帖子管理列表(后台）
     * 
     * @param businessArticle 帖子管理
     * @return 帖子管理集合
     */
    public List<BusinessArticleVo> selectBusinessArticleList(BusinessArticle businessArticle);


    /**
     * 查询帖子管理列表(xcx,结果包含likeFlag//用户点赞状态）
     * @param content 搜索内容
     * @param orderByColumn　需要排序的字段
     * @param descFlag　时间排序desc/asc
     * @return 帖子管理集合
     */
    public List<BusinessArticleVo> selectListForXcx(Long userId,String content,String orderByColumn,String descFlag);

    /**查询帖子详情
     *
     * @param userId 登录者id
     * @param articleId 帖子id
     * @return
     */
    BusinessArticleVo selectDetailForXcx(Long userId,Long articleId);

    /**xcx 热度话题列表*/
    String[] hotTagList();

/**xcx 我的 帖子列表*/
   List<BusinessArticleVo> selectListForXcxMy(Long userId);
    /**查询帖子详情
     *
     * @param userId 我的id
     * @param articleId 帖子id
     * @return
     */

   BusinessArticleVo selectDetailForXcxMy(Long userId,Long articleId);


    /**
     * 新增帖子管理
     * 
     * @param businessArticle 帖子管理
     * @return 结果
     */
    public int insertBusinessArticle(BusinessArticle businessArticle);

    /**
     * 修改帖子管理
     * 
     * @param businessArticle 帖子管理
     * @return 结果
     */
    public int updateBusinessArticle(BusinessArticle businessArticle);

    /**
     * 逻辑批量删除帖子管理
     * 
     * @param articleIds 需要删除的帖子管理主键集合
     * @return 结果
     */
    public int deleteBusinessArticleByArticleIds(Long[] articleIds);

    /**
     * 删除帖子管理信息
     * 
     * @param articleId 帖子管理主键
     * @return 结果
     */
    public int deleteBusinessArticleByArticleId(Long articleId);
}
